@@ -252,7 +252,7 @@ QDomElement Message::toQDomElement(QDomDocument doc, Message src)
     return ret;
 }
 
-const QString Message::subject()
+const QString Message::subject() const
 {
     if (this->title().isEmpty() || this->title().trimmed().compare(DEFAULT_SUBJECT) == 0)
     {
@@ -262,7 +262,7 @@ const QString Message::subject()
 }
 
 // Choose subject for message as begin of body
-QString Message::subjectFromBody(QString messageBody)
+QString Message::subjectFromBody(QString messageBody) const
 {
     messageBody = messageBody.simplified();
     if (messageBody.isEmpty()) {
@@ -324,3 +324,9 @@ QString Message::deleteMessageKey(const QString &accountId, const QString &messa
 {
     return QString("deleteMessage_%1_%2").arg(accountId).arg(messageId);
 }
+
+bool Message::operator==(const Message &m) const
+{
+    return d->accountId == m.d->accountId
+            && d->messageId == m.d->messageId;
+}
