@@ -29,7 +29,8 @@ private:
     AccountList mAccountList;
 
     QSet<QString> mLocalAccountIds;
-    QSet<QString> mCachedDraftIds;
+    QSet<QString> mCachedDraftIds; // TODO: it is unneeded if:
+                                   // message is draft <=> message.isSended and message isReceived are false
 
     void updateLocalCache();
 
