@@ -12,20 +12,24 @@ class FilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
+    FilterModel(QObject* parent = 0);
     FilterModel(ServiceMgr* smgr, QObject* parent = 0);
 
     QString getServiceId(const QVariant& data) const;
 
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const;
+    //bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
 
-private slots:
+public slots:
     void setFilteredDriver(DriverInfo* driver);
+    void setFilterString(const QString& str);
 
 private:
     ServiceMgr* mServiceMgr;
     FilterManager* mFilterMgr;
     ServiceFilter* mServiceFilter;
+    QString mFilterString;
 
     DriverInfo* mFilteredDriver;
 };
