@@ -80,6 +80,7 @@ public:
         getListPhotosAction, /**< \brief Class: photos. Method: getListPhotos. */
         getCommentsAction, /**< \brief Class: photos. Method: getListPhotoComments. */
         sendCommentAction, /**< \brief Class: photos. Method: sendPhotoComment. */
+        createAlbumAction, /**< \brief Class: photos. Method: createAlbum. */
         getListAlbumsAction, /**< \brief Class: photos. Method: getListAlbums. */
         getFeedAction /**< \brief Class: news. Method: getListNews. */
     };
@@ -194,6 +195,12 @@ public:
       */
     void getProfile(const QString& ownerId);
 
+    void getStatusMessage();
+
+    void getStatusMessage(const QString& ownerId);
+
+    void getStatusMessage(Friend& fr);
+
     void getFriends(bool alsoLoadIcons);
     bool deleteFriend(QString ownerId);
     bool deleteFriend(Friend owner);
@@ -208,7 +215,7 @@ public:
     void downloadPhotoList(PhotoList list, Photo curPhoto, int nearest);
 
     /*!
-      \brief loalist of messages from service.
+      \brief load list of messages from service.
 
       Uses \a getInbox(), \a getOutbox() and \a getThreads().
       */
@@ -246,6 +253,7 @@ public:
     void getFeed(QEventFeed::FeedType type);
 
     QStatInfo getStats() const;
+    bool createAlbum(QString name, QString description, QString privacy);
 
 signals:
     void albumsReceived(QString accountid, QString friendId, AlbumList, bool isLastUpdate);
@@ -258,6 +266,7 @@ signals:
 
     void settingsReceived(QString accountid, QString) const;
     void profileReceived(QString accountId, QString reqOwnerId, Friend data);
+    void statusMessageReceived(QString accountId, QString ownerId, QString message);
 
     void messagesReceived(QString accountId, MessageList list, bool isLastUpdate);
     void messageSended(QString accountId, QString ownerId, QString title, QString text);
