@@ -579,7 +579,6 @@ MessageList ServiceMgr::getMessages(bool isNeedUpdate, bool useSignal)
 
     for (int i = 0; i < this->accounts.length(); i++) {
         if (this->accounts.at(i)->isDisabled()) continue;
-        //if (isServiceFiltered(accounts[i])) continue;
 
         MessageList curList = this->accounts.at(i)->getMessageList();
         ret.append(curList);
@@ -616,7 +615,7 @@ void ServiceMgr::gotMessageList(QString accountId, MessageList list, bool isLast
 
     for (int i = 0; i < this->accounts.length(); i++) {
         if (this->accounts.at(i)->isDisabled()) continue;
-        //if (isServiceFiltered(accounts[i]) && !isLastUpdate) continue;
+
         if (this->accounts[i]->transport->accountId() == accountId) {
             this->accounts[i]->setMessageList(list);
             ret.append(list);
@@ -626,6 +625,9 @@ void ServiceMgr::gotMessageList(QString accountId, MessageList list, bool isLast
             ret.append(lst);
             qDebug() << "Add to messages " << lst.length() << ". Total:" << ret.length();
         }
+
+        MessageList draftList = this->accounts.at(i)->getDraftMessages();
+        ret.append(draftList);
     }
 
     if (isLastUpdate)
